@@ -42,16 +42,19 @@ int main (int argc, char *argv[]);
 
 /* menu bar */
 GnomeUIInfo file_menu[] = {
-	{ GNOME_APP_UI_ITEM, N_("New _Folder..."), NULL, create_folder_pressed, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW, 'F',
-	  GDK_CONTROL_MASK, NULL },
+        GNOMEUIINFO_MENU_NEW_ITEM(N_("_New Folder..."),
+				  N_("Create a new folder"),
+				  create_folder_pressed, NULL),
+	
 	{ GNOME_APP_UI_ITEM, N_("_Delete..."), NULL, delete_pressed_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CUT, 'D',
 	  GDK_CONTROL_MASK, NULL },
-	{ GNOME_APP_UI_ITEM, N_("_Quit"), NULL, destroy_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'Q',
-	  GDK_CONTROL_MASK, NULL },
-	{ GNOME_APP_UI_ENDOFINFO }
+
+	GNOMEUIINFO_SEPARATOR,
+
+	GNOMEUIINFO_MENU_EXIT_ITEM(destroy_cb, NULL),
+
+	GNOMEUIINFO_END
 };
 GnomeUIInfo sort_menu[] = {
 	{ GNOME_APP_UI_ITEM, N_("_Sort Folder"), NULL, sort_single_pressed, NULL, NULL,
@@ -65,9 +68,7 @@ GnomeUIInfo sort_menu[] = {
 GnomeUIInfo help_menu[] = {
 /*	{ GNOME_APP_UI_HELP, NULL, NULL, NULL, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },*/
-	{ GNOME_APP_UI_ITEM, N_("_About..."), NULL, about_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, 0, 0,
-	  NULL },
+        GNOMEUIINFO_MENU_ABOUT_ITEM(about_cb, NULL), 
 	{ GNOME_APP_UI_ENDOFINFO }
 };
 GnomeUIInfo main_menu[] = {
