@@ -358,7 +358,7 @@ GtkCTreeNode *add_leaf_node(GtkCTree *ctree, GtkCTreeNode *parent, GtkCTreeNode
 
 	parent_data = gtk_ctree_node_get_row_data(GTK_CTREE(ctree), parent);
 
-	path_buf = g_copy_strings (parent_data->path, "/", file, NULL);
+	path_buf = g_strconcat (parent_data->path, "/", file, NULL);
 				
 	if (!g_file_exists(path_buf))
 		{
@@ -454,13 +454,7 @@ void add_tree_node(GtkCTree *ctree, GtkCTreeNode *parent, GtkWidget *pbar)
 
 	if (orderlist)
 		{
-		int i;
-		int l = g_list_length(orderlist);
-		for (i=0;i<l;i++)
-			{
-			GList *list = g_list_nth(orderlist, i);
-			g_free(list->data);
-			}
+		g_list_foreach(orderlist,(GFunc)g_free,NULL);
 		g_list_free(orderlist);
 		}
 
