@@ -27,9 +27,6 @@ char **env;
 #define DEFAULT_FONT "-misc-fixed-medium-r-normal--20-200-75-75-c-100-iso8859-1"
 #define EXTRA 2
 
-/* Name of section to discard if --discard given.  */
-static char *discard_section = NULL;
-
 /* Initial geometry */
 char *geometry = 0;
 
@@ -80,6 +77,7 @@ struct terminal_config {
 	int shaded;
 	int background_pixmap;
 	char * pixmap_file;
+        char * window_title;                    /* the window title */
 } ;
 
 /* Initial command */
@@ -374,6 +372,7 @@ load_config (char *class)
 	cfg->shaded = gnome_config_get_bool ("shaded=false");
 	cfg->background_pixmap = gnome_config_get_bool ("background_pixmap=false");
 	cfg->pixmap_file = gnome_config_get_string ("pixmap_file");
+	cfg->window_title = NULL;
 
 	if (strcasecmp (fore_color, back_color) == 0)
 		/* don't let them set identical foreground and background colors */
@@ -505,9 +504,9 @@ apply_changes (ZvtTerm *term, struct terminal_config *newcfg)
 	set_color_scheme (term, cfg);
 
 	if (cfg->menubar_hidden)
-		gtk_widget_hide (app->menubar);
+		gtk_widget_hide (app->menubar->parent);
 	else
-		gtk_widget_show (app->menubar);
+		gtk_widget_show (app->menubar->parent);
 
 	return 0;
 }
@@ -645,7 +644,7 @@ font_changed (GtkWidget *w, preferences_t *prefs)
 {
 	char *font;
 	GtkWidget *peer;
-	if (GNOME_IS_FONT_PICKER(w)) {
+	if (GNOME_IS_FONT_PICKER(w)){
 		font = gnome_font_picker_get_font_name (GNOME_FONT_PICKER(w));
 		peer = gtk_object_get_user_data (GTK_OBJECT(w));
 		gtk_entry_set_text (GTK_ENTRY(peer), font);
@@ -1122,6 +1121,7 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 	gtk_widget_show_all (prefs->prop_win);
 }
 
+#ifdef NEED_UNUSED_FUNCTIONS
 static void
 color_ok (GtkWidget *w)
 {
@@ -1140,6 +1140,7 @@ color_cmd (void)
 	gtk_widget_hide (GTK_COLOR_SELECTION_DIALOG (c)->help_button);
 	gtk_widget_show (c);
 }
+#endif
 
 static void
 show_menu_cmd (GtkWidget *widget, ZvtTerm *term)
@@ -1150,7 +1151,7 @@ show_menu_cmd (GtkWidget *widget, ZvtTerm *term)
 	app = GNOME_APP (gtk_widget_get_toplevel (GTK_WIDGET (term)));
 	cfg = gtk_object_get_data (GTK_OBJECT (term), "config");
 	cfg->menubar_hidden = 0;
-	gtk_widget_show (app->menubar);
+	gtk_widget_show (app->menubar->parent);
 }
 
 static void
@@ -1162,17 +1163,16 @@ hide_menu_cmd (GtkWidget *widget, ZvtTerm *term)
 	app = GNOME_APP (gtk_widget_get_toplevel (GTK_WIDGET (term)));
 	cfg = gtk_object_get_data (GTK_OBJECT (term), "config");
 	cfg->menubar_hidden = 1;
-	gtk_widget_hide (app->menubar);
+	gtk_widget_hide (app->menubar->parent);
 }
 
 #define DEFINE_TERMINAL_MENU(name,text,cmd) \
 \
 static GnomeUIInfo name [] = {							 \
-	GNOMEUIINFO_ITEM_NONE (N_("_New terminal"), NULL, new_terminal),         \
+        GNOMEUIINFO_MENU_NEW_ITEM (N_("_New terminal"), N_("Creates a new terminal window"), new_terminal, NULL),         \
 /*	GNOMEUIINFO_ITEM_NONE (N_("_Save properties as Defaults"), NULL, save_preferences_cmd),	 */\
 	GNOMEUIINFO_SEPARATOR,\
 	GNOMEUIINFO_ITEM_NONE (text, NULL, cmd),\
-	GNOMEUIINFO_ITEM_STOCK (N_("_Properties..."), NULL, preferences_cmd, GNOME_STOCK_MENU_PROP), \
 	/* GNOMEUIINFO_ITEM_NONE (N_("C_olor selector..."), NULL, color_cmd), */\
 	GNOMEUIINFO_SEPARATOR, \
 	GNOMEUIINFO_ITEM_NONE (N_("_Close terminal"),    NULL, close_terminal_cmd), 	\
@@ -1182,19 +1182,21 @@ static GnomeUIInfo name [] = {							 \
 DEFINE_TERMINAL_MENU (gnome_terminal_terminal_menu_hide_menubar, N_("_Hide menubar"), hide_menu_cmd);
 DEFINE_TERMINAL_MENU (gnome_terminal_terminal_menu_show_menubar, N_("_Show menubar"), show_menu_cmd);
 	
-static GnomeUIInfo gnome_terminal_about_menu [] = {
-	GNOMEUIINFO_ITEM_STOCK (N_("_About..."), NULL,
-			       about_terminal_cmd, GNOME_STOCK_MENU_ABOUT),
-#if 0
-	GNOMEUIINFO_SEPARATOR, 
-	GNOMEUIINFO_HELP ("_Terminal"),
-#endif
+static GnomeUIInfo gnome_terminal_help_menu [] = {
+	GNOMEUIINFO_HELP ("gnome-terminal"),
+	GNOMEUIINFO_MENU_ABOUT_ITEM(about_terminal_cmd, NULL),
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo gnome_terminal_settings_menu [] = {
+        GNOMEUIINFO_MENU_PREFERENCES_ITEM(preferences_cmd, NULL),
 	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo gnome_terminal_menu [] = {
-	GNOMEUIINFO_SUBTREE (N_("Terminal"), &gnome_terminal_terminal_menu_hide_menubar),
-	GNOMEUIINFO_SUBTREE (N_("Help"),     &gnome_terminal_about_menu),
+	GNOMEUIINFO_MENU_FILE_TREE(gnome_terminal_terminal_menu_hide_menubar),
+	GNOMEUIINFO_MENU_SETTINGS_TREE(gnome_terminal_settings_menu),
+	GNOMEUIINFO_MENU_HELP_TREE(gnome_terminal_help_menu),
 	GNOMEUIINFO_END
 };
 
@@ -1240,16 +1242,16 @@ terminal_kill (GtkWidget *widget, void *data)
 static void
 title_changed(ZvtTerm *term, VTTITLE_TYPE type, char *newtitle)
 {
-  GnomeApp *window = GNOME_APP (gtk_widget_get_toplevel (GTK_WIDGET (term)));
+	GnomeApp *window = GNOME_APP (gtk_widget_get_toplevel (GTK_WIDGET (term)));
 
-  switch(type) {
-  case VTTITLE_WINDOW:
-  case VTTITLE_WINDOWICON:
-    gtk_window_set_title((GtkWindow *)window, newtitle);
-    break;
-  default:
-    break;
-  }
+	switch(type){
+	case VTTITLE_WINDOW:
+	case VTTITLE_WINDOWICON:
+		gtk_window_set_title((GtkWindow *)window, newtitle);
+		break;
+	default:
+		break;
+	}
 }
 
 
@@ -1503,7 +1505,13 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 	}
 
 	app = gnome_app_new ("Terminal", "Terminal");
+	/* override the title if it was in the config */
+	if (cfg->window_title) {
+	  gtk_window_set_title(GTK_WINDOW(app), cfg->window_title);
+ 	}
 	gtk_window_set_wmclass (GTK_WINDOW (app), "GnomeTerminal", "GnomeTerminal");
+	gtk_window_set_policy(GTK_WINDOW (app), TRUE, TRUE, TRUE);
+
 	if (cmd != NULL)
 		initial_term = app;
 
@@ -1551,7 +1559,7 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 	
 	gnome_app_create_menus_with_data (GNOME_APP (app), gnome_terminal_menu, term);
 	if (cfg->menubar_hidden)
-		gtk_widget_hide (GNOME_APP (app)->menubar);
+		gtk_widget_hide (GNOME_APP (app)->menubar->parent);
 	
 	/* Decorations */
 	hbox = gtk_hbox_new (0, 0);
@@ -1699,25 +1707,48 @@ save_session (GnomeClient *client, gint phase, GnomeSaveStyle save_style,
 	
 	i = 0;
 	for (list = terminals; list != NULL; list = list->next){
-	  
-		char *geom;
+	
+	        gint width, height, x, y;
+		GString *geom;
 		struct terminal_config *cfg;			
 		ZvtTerm *term;
-		GtkWidget *top = 
-			gtk_widget_get_toplevel (GTK_WIDGET (list->data));
-		char *prefix = g_strdup_printf ("%s%d/", file, i);
+		GtkWidget *top;
+		char *prefix;
 	  
-		gnome_config_push_prefix (prefix);
-
-		/* NAUGHTY: The ICCCM requires that the WM stores
-		   all session data on geometry! */
-		geom = gnome_geometry_string (top->window);
-		gnome_config_set_string ("geometry", geom);
-		g_free (geom);
-		
+		top = gtk_widget_get_toplevel (GTK_WIDGET (list->data));
+		prefix = g_strdup_printf ("%s%d/", file, i);
 		term = ZVT_TERM (gtk_object_get_data (GTK_OBJECT(list->data), 
 						      "term"));
 		cfg = gtk_object_get_data (GTK_OBJECT (term), "config");
+
+		gnome_config_push_prefix (prefix);
+
+		/*
+		 * NAUGHTY: The ICCCM requires that the WM stores
+		 * all session data on geometry!
+		 */
+
+		/*
+		 * we can't use gnome_geometry_string because we need
+		 * to calculate the terminal, not window size
+		 */
+		gdk_window_get_root_origin (top->window, &x, &y);
+
+		width = 
+		  (GTK_WIDGET (term)->allocation.width - 
+		   (GTK_WIDGET (term)->style->klass->xthickness * 2)) /
+		  term->charwidth;
+
+		height = 
+		  (GTK_WIDGET (term)->allocation.height - 
+		   (GTK_WIDGET (term)->style->klass->ythickness * 2)) /
+		  term->charheight;
+
+		geom = g_string_new ("");
+		g_string_sprintf (geom, "%dx%d+%d+%d", width, height, x, y);
+		gnome_config_set_string ("geometry", geom->str);
+		g_string_free (geom, TRUE);
+		
 		gnome_config_set_string("class", cfg->class);
 		
 		if (top == initial_term){
@@ -1773,7 +1804,8 @@ enum {
 	BACK_KEY     = -7,
 	CLASS_KEY    = -8,
 	DOUTMP_KEY   = -9,
-	DONOUTMP_KEY = -10
+	DONOUTMP_KEY = -10,
+        TITLE_KEY    = -11
 };
 
 static struct poptOption cb_options [] = {
@@ -1809,6 +1841,9 @@ static struct poptOption cb_options [] = {
 	{ "noutmp", '\0', POPT_ARG_NONE, NULL, DONOUTMP_KEY,
 	  N_("Do not update utmp/wtmp entries"), N_("NOUTMP") },
 	
+	{ "title", 't', POPT_ARG_STRING, NULL, TITLE_KEY,
+          N_("Set the window title"), N_("TITLE") },
+
 	{ NULL, '\0', 0, NULL, 0}
 };
 
@@ -1869,6 +1904,9 @@ parse_an_arg (poptContext state,
 	case DONOUTMP_KEY:
 		update_utmp = FALSE;
 		break;
+	case TITLE_KEY:
+	        cfg->window_title = g_strdup(arg);
+                break;
 	default:
 	}
 }
@@ -1953,6 +1991,11 @@ main_terminal_program (int argc, char *argv [], char **environ)
 		free (default_config->font);
 		default_config->font = g_strdup (cmdline_config->font);
 	}
+
+	/* override the title*/
+	if (cmdline_config->window_title) {
+	  default_config->window_title = cmdline_config->window_title;
+	}
 	
 	if (cmdline_config->have_user_colors){
 		default_config->color_set = cmdline_config->color_set;
@@ -1980,3 +2023,9 @@ main (int argc, char *argv [], char **environ)
 {
 	return main_terminal_program (argc, argv, environ);
 }
+
+/*
+ * Local variables:
+ * c-basic-offset: 8
+ * End:
+ */
