@@ -51,7 +51,7 @@ char *form_info_tag_href( char *nodefile, char *nodename )
   else
 	  filename = nodefile;
 
-  snprintf(tmp,sizeof(tmp),"HREF=\"info:%s#%s\"", filename, escaped_nodename );
+  g_snprintf(tmp,sizeof(tmp),"HREF=\"info:%s#%s\"", filename, escaped_nodename );
   if (escaped_nodename)
     g_free(escaped_nodename);
   return g_strdup(tmp);
@@ -915,4 +915,3 @@ void write_html_horiz_rule( FILE *f )
 {
   fprintf(f, "<HR>\n");
 }
-
